# jmu-sched

Tells you when the next "standard" class time ends.

## Data

Date comes from the
[JMU Class Scheduling Policy](https://www.jmu.edu/academic-affairs/policies-and-reports/class-schedule.shtml).
